@@ -1,7 +1,9 @@
 package Log::Any::IfLOG;
 
 our $DATE = '2015-04-02'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
+
+my $log_singleton;
 
 sub import {
     my $self = shift;
@@ -17,7 +19,8 @@ sub import {
     } else {
         my $saw_log_param = grep { $_ eq '$log' } @_;
         if ($saw_log_param) {
-            *{"$caller\::log"} = \Object::Dumb->new;
+            if (!$log_singleton) { $log_singleton = Object::Dumb->new }
+            *{"$caller\::log"} = \$log_singleton;
         }
     }
 }
@@ -42,7 +45,7 @@ Log::Any::IfLOG - Load Log::Any only if log-related environment variables are se
 
 =head1 VERSION
 
-This document describes version 0.03 of Log::Any::IfLOG (from Perl distribution Log-Any-IfLOG), released on 2015-04-02.
+This document describes version 0.04 of Log::Any::IfLOG (from Perl distribution Log-Any-IfLOG), released on 2015-04-02.
 
 =head1 SYNOPSIS
 
@@ -58,10 +61,10 @@ accept any method but return false.
 
 This is a quick-hack solution to avoid the cost of loading Log::Any under
 "normal condition" (when log-enabling variables/flags are not set to true).
-Since Log::Any 1.00, startup overhead increases to about 7ms on my PC (from
-under 1ms for the previous version). Since I want to keep startup overhead of
-CLI apps under 50ms (see L<Perinci::CmdLine::Lite>) to keep tab completion from
-getting a noticeable lag, every millisecond counts.
+Since Log::Any 1.00, startup overhead increases to about 7-10ms on my PC/laptop
+(from under 1ms for the previous version). Since I want to keep startup overhead
+of CLI apps under 50ms (see L<Perinci::CmdLine::Lite>) to keep tab completion
+from getting a noticeable lag, every millisecond counts.
 
 =for Pod::Coverage ^(.+)$
 
